/********************************************************************************
** Form generated from reading UI file 'configuredialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGUREDIALOG_H
#define UI_CONFIGUREDIALOG_H

#include <LXQtGlobalKeysUi/ShortcutSelector>
#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ConfigureDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout_2;
    QLabel *label;
    QComboBox *positionCbx;
    QLabel *marginLabel;
    QSpinBox *marginSB;
    QLabel *widthLabel;
    QSpinBox *widthSB;
    QLabel *label_2;
    QComboBox *monitorCbx;
    QLabel *label_4;
    QSpinBox *listShownItemsSB;
    QCheckBox *historyUseCb;
    QCheckBox *historyFirstCb;
    QCheckBox *clearCb;
    QHBoxLayout *horizontalLayout;
    QFormLayout *formLayout;
    QLabel *labelShortcut;
    ShortcutSelector *shortcutEd;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ConfigureDialog)
    {
        if (ConfigureDialog->objectName().isEmpty())
            ConfigureDialog->setObjectName("ConfigureDialog");
        ConfigureDialog->resize(312, 278);
        verticalLayout = new QVBoxLayout(ConfigureDialog);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(ConfigureDialog);
        groupBox->setObjectName("groupBox");
        formLayout_2 = new QFormLayout(groupBox);
        formLayout_2->setObjectName("formLayout_2");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        positionCbx = new QComboBox(groupBox);
        positionCbx->setObjectName("positionCbx");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, positionCbx);

        marginLabel = new QLabel(groupBox);
        marginLabel->setObjectName("marginLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, marginLabel);

        marginSB = new QSpinBox(groupBox);
        marginSB->setObjectName("marginSB");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, marginSB);

        widthLabel = new QLabel(groupBox);
        widthLabel->setObjectName("widthLabel");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, widthLabel);

        widthSB = new QSpinBox(groupBox);
        widthSB->setObjectName("widthSB");
        widthSB->setMaximum(100);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, widthSB);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        monitorCbx = new QComboBox(groupBox);
        monitorCbx->setObjectName("monitorCbx");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, monitorCbx);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        listShownItemsSB = new QSpinBox(groupBox);
        listShownItemsSB->setObjectName("listShownItemsSB");
        listShownItemsSB->setMinimum(1);

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, listShownItemsSB);

        historyUseCb = new QCheckBox(groupBox);
        historyUseCb->setObjectName("historyUseCb");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::SpanningRole, historyUseCb);

        historyFirstCb = new QCheckBox(groupBox);
        historyFirstCb->setObjectName("historyFirstCb");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::SpanningRole, historyFirstCb);

        clearCb = new QCheckBox(groupBox);
        clearCb->setObjectName("clearCb");

        formLayout_2->setWidget(7, QFormLayout::ItemRole::SpanningRole, clearCb);


        verticalLayout->addWidget(groupBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        labelShortcut = new QLabel(ConfigureDialog);
        labelShortcut->setObjectName("labelShortcut");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelShortcut);

        shortcutEd = new ShortcutSelector(ConfigureDialog);
        shortcutEd->setObjectName("shortcutEd");
        shortcutEd->setMinimumSize(QSize(81, 0));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, shortcutEd);


        horizontalLayout->addLayout(formLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 38, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(ConfigureDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ConfigureDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ConfigureDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ConfigureDialog, qOverload<>(&QDialog::reject));
        QObject::connect(historyUseCb, &QCheckBox::toggled, historyFirstCb, &QCheckBox::setEnabled);

        QMetaObject::connectSlotsByName(ConfigureDialog);
    } // setupUi

    void retranslateUi(QDialog *ConfigureDialog)
    {
        ConfigureDialog->setWindowTitle(QCoreApplication::translate("ConfigureDialog", "Runner Settings", nullptr));
        groupBox->setTitle(QCoreApplication::translate("ConfigureDialog", "Appearance", nullptr));
        label->setText(QCoreApplication::translate("ConfigureDialog", "Positioning:", nullptr));
        marginLabel->setText(QCoreApplication::translate("ConfigureDialog", "Top margin", nullptr));
        marginSB->setSuffix(QCoreApplication::translate("ConfigureDialog", " px", nullptr));
        widthLabel->setText(QCoreApplication::translate("ConfigureDialog", "Width:", nullptr));
#if QT_CONFIG(tooltip)
        widthSB->setToolTip(QCoreApplication::translate("ConfigureDialog", "With multiple screens, if the window is shown on the focused screen,\n"
"this value is only for the smallest screen. The minimum width is 400 px.", nullptr));
#endif // QT_CONFIG(tooltip)
        widthSB->setSuffix(QCoreApplication::translate("ConfigureDialog", "%", nullptr));
        label_2->setText(QCoreApplication::translate("ConfigureDialog", "Show on:", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(QCoreApplication::translate("ConfigureDialog", "<b>Note</b>: The size of top-level widgets are constrained to 2/3 of the desktop's height and width.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(QCoreApplication::translate("ConfigureDialog", "Show list with:", nullptr));
        listShownItemsSB->setSuffix(QCoreApplication::translate("ConfigureDialog", " item(s)", nullptr));
        historyUseCb->setText(QCoreApplication::translate("ConfigureDialog", "Store/show history", nullptr));
        historyFirstCb->setText(QCoreApplication::translate("ConfigureDialog", "Show history first", nullptr));
        clearCb->setText(QCoreApplication::translate("ConfigureDialog", "Clear input on launching", nullptr));
        labelShortcut->setText(QCoreApplication::translate("ConfigureDialog", "Shortcut:", nullptr));
        shortcutEd->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ConfigureDialog: public Ui_ConfigureDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGUREDIALOG_H
